@@ -1,8 +1,6 @@
 from PythUnity.Classes import Object
 from PythUnity.Classes import String
-from PythUnity.Functions import AddPrefab
-from PythUnity.Functions import GetPrefab
-from PythUnity.Functions import PrintFonts
+from PythUnity.Functions import *
 from PythUnity.Variables import *
 from PythUnity.main import init
 from pygame import Rect
\ No newline at end of file
